/* DETROIT_FORWARD_BACKWARD_LOOKING_RENTAL_DYNAMICS.SAS */

/* Written by Fouad Moumen April 2 For DETROIT Metro Area as modified version of the code written by Fouad 
for Houston and was modified and ran by Dav April 1 */ 

/* The Code is intended to Generate DETROIT FORWARD and BACKWARD CINCH RENTAL DYNAMICS Tables for 
DETROIT Metro area.

For the DETROIT Forward Cinch Rental Dynamics: The code merges five files, AHS.AHS2015n IUF, 
AHS.AHS2017n IUF, and OUT.AHSCaseHistory2015to2017 (called WDTG by Fred), the HADS.HADS2015N 
and HADS.HADS2017N keeping all cases, and then merging with the DETROIT Forward looking CINCH 
weights file called OUT.FLCINCH_DETROIT_SKINNY provided by Fouad to Dav Keeping keeping only 
those cases in FLCINCH_DETROIT_SKINNY.  

The file FLCINCH_DETROIT_SKINNY is a SAS data set PREPARED BY Fouad Moumen from the Forward-Looking analysis 
and contains four variables: INTSAME INTLOSS CONTROL FLCINCHWT. THE Control numbers 
presented in the skinny file are for DETROIT METRO AREA where OMB13CBSA = 19820, The variable  OMB13CBSA
is in the WDTG file. This data set is emailed to Dav along with this code, and will be saved by Dav 
in a folder named by him. That folder name will be used by him to define the Library "OUT"

For the DETROIT Backward Cinch Rental Dynamics: The code merges five files: AHS.AHS2015n IUF, AHS.AHS2017n IUF, 
and OUT.AHSCaseHistory2015to2017 (called WDTG by Fred), the HADS.HADS2015N and HADS.HADS2017N keeping all cases, 
and then merging with the BACKWARD looking CINCH weights file called OUT.BLCINCH_DETROIT_SKINNY provided by 
Fouad to Dav Keeping only those cases in BLCINCH_DETROIT_SKINNY. 

The file BLCINCH_DETROIT_SKINNY is a SAS data set PREPARED BY Fouad Moumen from the BACKWARD-Looking analysis 
and contains SIX variables: INTSAME, INTADD, NC, OTHNEW, OTHB, CONTROL, and BLCINCHWT. The control cases 
represented in this Skinny file present the DETROIT Metro area where OMB13CBSA = 19820. 
The variable  OMB13CBSA is in the WDTG file. This data set is emailed to Dav along with this code, and will 
be saved by Dav in a folder named by him. That folder name will be used by him to define the Library "OUT"

DAV MODIFICATION:  The case history file is in the AHS library, NOT OUT.  Note also that
the HADS and AHS libnames point to the same directory.
*/


TITLE "2015-2017 DETROIT Forward and Backward Looking Weighted and Unweighted Rental Dynamics Tables";RUN;

/* NOTE: The Tables will be saved in one Excel Sheet Defined as 
    DETROIT_FORWARD_BACKWARD_LOOKING_RENTAL_DYNAMICS_TABLES_Fred */


/* Dav's Standard options */
OPTIONS
      NOCENTER NODATE NONUMBER
      LINESIZE=120 PAGESIZE=32627
      COMPRESS=BINARY
      FMTSEARCH=(Common) 
      NOFMTERR
      cmplib=sasuser.userfuncs
      ; * end of options;

/* USER SETTINGS ---------------------------------------------------------------------------------*/


/* Assuming that the required two AHS2015n and AHS2017n SAS files exist in the libname (AHS) defined below.
Also assuming that the two HADS2015N and HADS2017N SAS files exist in the library (HADS) defined below, and
finally assume that the two sas files AHSCaseHistory2015to2017, FLCINCH_DETROIT_SKINNY, and BLCINCH_DETROIT_SKINNY  
exist in the libname (OUT) defined by Dav */

LIBNAME AHS "M:\ADDP\Housing Team\HUD\2017 AHS\Custom Tabulations\SP Group\Rental dynamics\Data"; /* Dav mod to point to local folder */

LIBNAME HADS "M:\ADDP\Housing Team\HUD\2017 AHS\Custom Tabulations\SP Group\Rental dynamics\Data"; /* Dav mod to point to local folder */

LIBNAME OUT "M:\ADDP\Housing Team\HUD\2017 AHS\Custom Tabulations\SP Group\Rental dynamics\Data\Houston"; /* Dav mod to point to local folder */


/* This SAS code (DETROIT_FORWARD_LOOKING_RENTAL_DYNAMICS.SAS) along with the skinny files, FLCINCH_DETROIT_skinny sas
and BLCINCH_DETROIT_skinny data files are saved in Fouad's Computer folder  C:\NEW_AHS_2018\DOWN LOADED DATA 
AS OF March  2020 */

/* The Tables produced by this code are saved in the Excel Spread sheet Defined below by Dav Unless 
it is Changed by Dav.  Dav, Please check the correctiness of the Excel spreadsheet location*/


%LET SpreadDir = M:\ADDP\Housing Team\HUD\2017 AHS\Custom Tabulations\SP Group\Rental dynamics\Spreadsheets\Houston\; /* Added by dav.  directory for spreadsheets */

%LET SpreadVer = Ver 200401 1452;   /* added by dav.  version tag for spreadsheets */

/*  The spread sheet statement was moved to be after the data manupolation   */
/* END OF USER SETTINGS --------------------------------------------------------------------------*/

                  /* Custom formats go here */

PROC FORMAT;   

     VALUE FLRENT 

0 = '0-Not rental in 2015'

1 = '1-Non-market: Either no cash rent or a subsidized rent'         
          
2 = '2-Extremely low rent: may or not affordable to renters with incomes<30% of median income'

3 = '3-Very low rent: affordable to renters with incomes>=30% percent of median income'

4 = '4-Low rent: affordable to renters with income>=50% of median income'

5 = '5-Moderate rent: affordable to renters with incomes>=80% of median income'

6 = '6-High rent: affordable to renters with incomes>=median income'

7 = '7-Very high rent: affordable to renters with incomes>=120% of median income'

8 = '8-All other rental units with cash rents';


/* end of FLRENT */


VALUE  FLRENTM

0 = '0-Not rental in 2015'

2 = '1-Assisted, or very low rent in 2015'

5 = '5-Moderate rent in 2015'

7 = '7-High rent in 2015' ;

/* end of FLRENTM */



      VALUE FLAFFORD

0 ='00-some other outcome'

1 ='01-Non-market rental: Either no cash rent or a subsidized rent'

2 ='02-Extremely low rent: may or not affordable to renters with incomes<30% of median income'

3 ='03-Very low rent: affordable to renters with incomes>=30% percent of median income'

4 ='04-Low rent: affordable to renters with income>=50% of median income'

5 ='05-Moderate rent: affordable to renters with incomes>=80% of median income'

6 ='06-High rent: affordable to renters with incomes>=median income'

7 ='07-Very high rent: affordable to renters with incomes>=120% of median income'

8 ='08-All other rental units with cash rents' 

9 ='09-A 2017 owner-unit (occupied or vacant)'

10 ='10-A 2017 seasonal or URE unit' 

11 ='11-A temporary lost to the stock in 2017'

12 ='12-A permanent lost to the stock in 2017';
    
/* end of FLAFFORD */


VALUE FLAFFORDM

0 = '00-Not rental in 2017'

2 = '01-Assisted, or very low rent in 2017'

5 = '05-Moderate rent in 2017'

7 = '07-High rent in 2017' 

9 = '09-Owner or seasonal in 2017'

12= '12-Lost by 2017';

/* end of FLAFFORDM */

     VALUE BLRENT 

0 = '0-Not rental in 2017'

1 = '1-Non-market: Either no cash rent or a subsidized rent'         
          
2 = '2-Extremely low rent: may or not affordable to renters with incomes<30% of median income'

3 = '3-Very low rent: affordable to renters with incomes>=30% percent of median income'

4 = '4-Low rent: affordable to renters with income>=50% of median income'

5 = '5-Moderate rent: affordable to renters with incomes>=80% of median income'

6 = '6-High rent: affordable to renters with incomes>=median income'

7 = '7-Very high rent: affordable to renters with incomes>=120% of median income'

8 = '8-All other rental units with cash rents';


/* end of BLRENT */

VALUE BLRENTM

0 = '0-Not rental in 2017'

2 = '1-Assisted, or very low rent in 2017'

5 = '5-Moderate rent in 2017'

7 = '7-High rent in 2017' ;

/* end of BLRENTM */


      VALUE BLAFFORD

0 ='00-some other outcome'

1 ='01-Non-market rental: Either no cash rent or a subsidized rent'

2 ='02-Extremely low rent: may or not affordable to renters with incomes<30% of median income'

3 ='03-Very low rent: affordable to renters with incomes>=30% percent of median income'

4 ='04-Low rent: affordable to renters with income>=50% of median income'

5 ='05-Moderate rent: affordable to renters with incomes>=80% of median income'

6 ='06-High rent: affordable to renters with incomes>=median income'

7 ='07-Very high rent: affordable to renters with incomes>=120% of median income'

8 ='08-All other rental units with cash rents' 

9 ='09-A 2015 owner-unit (occupied or vacant)'

10 ='10-A 2015 seasonal or URE unit' 

11 ='11-A new construction addition in 2017'

12 ='12-An other addition in 2017'

13 ='13-A recovery of a 2015 temporary loss'; 
    
/* end of BLAFFORD */

VALUE BLAFFORDM

0 = '00-Not rental in 2015'

2 = '01-Assisted, or very low rent in 2015'

5 = '05-Moderate rent in 2015'

7 = '007-High rent in 2015' 

9 = '9-Owner or seasonal in 2015'

11= '11-Added by 2017';

/* end of BLAFFORDM */

RUN:

/*                  DATA MANIPULATION                 */


/*    STEP 1 Reading and Sorting FILES                 */

DATA AHS2017; SET AHS.AHS2017N (WHERE=(SUBSTR(Control,1,2) = '11'));

IN17_TENURE=TENURE;
IN17_HUDSUB_IUF=HUDSUB_IUF;
IN17_VACANCY=VACANCY;  RUN;

PROC SORT DATA=AHS2017; BY CONTROL; RUN;

DATA AHS2015; SET AHS.AHS2015N (WHERE=(SUBSTR(Control,1,2) = '11'));

IN15_TENURE=TENURE;
IN15_HUDSUB_IUF=HUDSUB_IUF;
IN15_VACANCY=VACANCY;  RUN;

PROC SORT DATA=AHS2015; BY CONTROL; RUN;

DATA HADS2017; SET HADS.HADS2017N;

IN17_OWNRENT=OWNRENT;
IN17_COSTRELAMICAT=COSTRELAMICAT;RUN;

PROC SORT DATA=HADS2017; BY CONTROL; RUN;

DATA HADS2015; SET HADS.HADS2015N;

IN15_OWNRENT=OWNRENT;
IN15_COSTRELAMICAT=COSTRELAMICAT;RUN;

PROC SORT DATA=HADS2015; BY CONTROL; RUN;


PROC SORT DATA=AHS.AHSCaseHistory2015to2017 ; BY CONTROL;RUN; /* libname changed by Dav */

PROC SORT DATA=OUT.FLCINCH_DETROIT_SKINNY ; BY CONTROL;RUN;

PROC SORT DATA=OUT.BLCINCH_DETROIT_SKINNY ; BY CONTROL;RUN;

************************************************************************************************;

/*   Define the variables FLRENT, FLAFFORD, FLRENTM, and FLAFFORDM codes  in two steps */

/* Step 1:Merging some of the files defined above and keeping cases that are defined in the OUT.FLCINCH_DETROIT_SKINNY file  */

DATA FLCINCH_DATA; MERGE AHS2017 (IN=AHS17) AHS2015 (IN=AHS15) HADS2017 (IN=HADS17)

HADS2015 (IN=HADS15) AHS.AHSCaseHistory2015to2017 (IN=WDTG) OUT.FLCINCH_DETROIT_SKINNY (IN=FLCINCH); /* case history libname changed by Dav */

BY CONTROL; IF FLCINCH=1; 

* Note missing command;
     missing B D R X _ H M N;
     MISSING b d r m n;

RUN;

/*  STEP 2  CODE FOR FLRENT, FLAFFORD, FLRENTM, and FLAFFORDM FROM THE MERGED DATA     */


DATA FLCINCH_DATA; SET  FLCINCH_DATA;

/*  These three conditions are added to remove the missing values of FLRENT and FLAFFORD    */

   IF IN15_OWNRENT = '1' THEN DELETE;

   IF INTSTATUS15 = '2' THEN DELETE;

   IF IN15_VACANCY IN('06', '07', '08', '09', '10', '11') THEN DELETE;

/* Here is the code for FLRENT (affordability of units that are rental in 2015) */



   FLRENT= 0;

IF IN15_OWNRENT='2' THEN FLRENT=IN15_COSTRELAMICAT + 1;

IF IN15_TENURE='3' OR IN15_HUDSUB_IUF IN('1','2','3') THEN FLRENT=1;



/* Here is the code for FLRENTM (affordability of units that are rental in 2015) Compressed values of FLRENT */


FLRENTM = 0;

IF FLRENT IN(1,2,3)     THEN FLRENTM = 2;

IF FLRENT IN(4,5)	THEN FLRENTM = 5;

IF FLRENT IN(6,7,8)     THEN FLRENTM = 7;


/* Here is the code for FLAFFORD (2017 status of 2015 rental units and, if still rental in 2017, 
          their affordability in 2017) */


FLAFFORD=0;

/* The following code was modified by Fred on 3/2/2020 */

IF IN17_OWNRENT='2' THEN FLAFFORD=IN17_COSTRELAMICAT + 1;

IF (IN17_TENURE='3' OR IN17_HUDSUB_IUF IN('1','2','3')) THEN FLAFFORD=1;

IF IN17_OWNRENT='1' THEN FLAFFORD=9; 

IF (INTSTATUS17='2' OR IN17_VACANCY IN('06','07','08','09','10','11')) THEN FLAFFORD=10;


IF (NOINT17 GE 10) THEN FLAFFORD=11; 

IF (NOINT17 GE 30) THEN FLAFFORD=12; 

/* Here is the code for FLAFFORDM (2017 status of 2015 rental units and, if still rental in 2017, 
          their affordability in 2017) compressed values of FLAFFORD */

FLAFFORDM = 0; 

IF FLAFFORD IN(1,2,3)   THEN FLAFFORDM = 2;

IF FLAFFORD IN(4,5)     THEN FLAFFORDM = 5;

IF FLAFFORD IN(6,7,8)   THEN FLAFFORDM = 7;

IF FLAFFORD IN(9,10)    THEN FLAFFORDM = 9;

IF FLAFFORD IN(11,12)   THEN FLAFFORDM = 12;


RUN;

************************************************************************************************;
/*   Define the variables BLRENT, BLAFFORD, BLRENTM, and BLAFFORDM codes  in two steps */

/* Step 1:Merging some of the files defined above and keeping cases that are defined in the 
OUT.BLCINCH_DETROIT_SKINNY file  */

DATA BLCINCH_DATA; MERGE AHS2017 (IN=AHS17) AHS2015 (IN=AHS15) HADS2017 (IN=HADS17)
HADS2015 (IN=HADS15) AHS.AHSCaseHistory2015to2017 (IN=WDTG) OUT.BLCINCH_DETROIT_SKINNY (IN=BLCINCH);  /* case history library changed by dav */
BY CONTROL; IF BLCINCH=1; 

* Note missing command;
     missing B D R X _ H M N;
     MISSING b d r m n;

RUN;

/*    STEP 2  CODE FOR BLRENT, BLAFFORD, BLRENTM, and BLAFFORDM FROM THE MERGED DATA     */


DATA BLCINCH_DATA; SET  BLCINCH_DATA;

IF IN17_OWNRENT='1' then DELETE;

IF  INTSTATUS17 = '2' then DELETE;

 IF IN17_VACANCY IN('06', '07', '08', '09', '10', '11') THEN DELETE;

/* Here is the code for BLRENT (affordability of units that are rental in 2017) */

BLRENT = 0;

IF IN17_OWNRENT='2' THEN BLRENT = IN17_COSTRELAMICAT + 1;

IF IN17_TENURE='3' OR IN17_HUDSUB_IUF IN('1','2','3') THEN BLRENT=1;


/* Here is the code for BLRENTM (affordability of units that are rental in 2017) */

BLRENTM = 0;

IF BLRENT IN(1,2,3) THEN BLRENTM = 2;

IF BLRENT IN(4,5)	THEN BLRENTM = 5;

IF BLRENT IN(6,7,8) THEN BLRENTM = 7;



/* Here is the code for BLAFFORD (2015 status of 2017 rental units and, if rental in 2015, 
          their affordability in 2015) */

BLAFFORD = 0;

IF IN15_OWNRENT='2' THEN BLAFFORD = IN15_COSTRELAMICAT + 1;

IF (IN15_TENURE='3' OR IN15_HUDSUB_IUF IN('1','2','3')) THEN BLAFFORD=1;

IF IN15_OWNRENT='1' THEN BLAFFORD=9; 

IF (INTSTATUS15='2' OR IN15_VACANCY IN('06','07','08','09','10','11')) THEN BLAFFORD=10; 

IF NC= 1 THEN BLAFFORD=11; 

IF OTHNEW = 1 THEN BLAFFORD=12; 

IF OTHB =1 THEN BLAFFORD=13; 


/* Here is the code for BLAFFORDM (2015 status of 2017 rental units and, if rental in 2015, 
          their affordability in 2015) */

BLAFFORDM = 0; 

IF BLAFFORD IN(1,2,3) THEN BLAFFORDM = 2;

IF BLAFFORD IN(4,5) THEN BLAFFORDM = 5;

IF BLAFFORD IN(6,7,8) THEN BLAFFORDM = 7;

IF BLAFFORD IN(9,10) THEN BLAFFORDM = 9;

IF BLAFFORD IN(11,12,13) THEN BLAFFORDM = 11;


RUN;

/*  end of Data Manipulation    */



/*Here is the analysis Fred  wanted to do:
	Do unweighted and weighted frequency distributions of FLRENTM and FLAFFORDM
	Do an unweighted and weighted crosstab of FLRENTM*FLAFFORDM 

       Do unweighted and weighted frequency distributions of BLRENTM and BLAFFORDM
	Do an unweighted and weighted crosstab of BLRENTM*BLAFFORDM 

                 All given in one Spreadsheet  
*/

ODS LISTING CLOSE;	/* added by dav */
ods HTML file="&SpreadDir.DETROIT_FORWARD_BACKWARD_LOOKING_RENTAL_DYNAMICS_TABLES_Fred_&Spreadver..XLS";


/*  The following two Cross Tabs (one Weighted and one Unweighted) are showing the groups of 
FLRENTM and FLAFFORDM Formatted  */


TITLE "Weighted Cross Tab of FLRENTM and FLAFFORDM for 15-17 METRO (DETROIT) Forward CINCH ANALYSIS (weight=FLCINCHWT) 
(Values of both FLRENTM and FLAFFORDM are formatted)"; run;

PROC FREQ DATA=FLCINCH_DATA FORMCHAR(1,2,7)='   ' ; 
	TABLE  FLRENTM*FLAFFORDM/MISSING nocol norow nopercent F=Thousands.; /* Dav added format */
	FORMAT FLRENTM FLRENTM. FLAFFORDM FLAFFORDM.; 
	WEIGHT FLCINCHWT; 
RUN;

TITLE "Unweighted Cross Tab of FLRENTM and FLAFFORDM for METRO (DETROIT) 15-17 Forward CINCH ANALYSIS
 (Values of both FLRENTM and FLAFFORDM are formatted)"; run;

PROC FREQ DATA=FLCINCH_DATA FORMCHAR(1,2,7)='   ' ; 
	TABLE  FLRENTM*FLAFFORDM/MISSING nocol norow nopercent F=COMMA6.;	/* Dav added format */
	FORMAT FLRENTM FLRENTM. FLAFFORDM FLAFFORDM.; 
RUN;

****************************************************************************************;

/*  The following two Cross Tabs (one Weighted and one Unweighted) are showing the groups of BLRENTM and BLAFFORDM Formatted  */


TITLE "Weighted Cross Tab of BLRENTM and BLAFFORDM for 17-15 METRO (DETROIT) BACKWARD CINCH ANALYSIS (weight=BLCINCHWT) 
(Values of both BLRENTM and BLAFFORDM are formatted)"; run;

PROC FREQ DATA=BLCINCH_DATA FORMCHAR(1,2,7)='   ' ; 
	TABLE  BLRENTM*BLAFFORDM/MISSING nocol norow nopercent F=Thousands.; /* dav added format */
	FORMAT BLRENTM BLRENTM. BLAFFORDM BLAFFORDM.; WEIGHT BLCINCHWT; 
RUN;

TITLE "Unweighted Cross Tab of BLRENTM and BLAFFORDM for 17-15 METRO (DETROIT) BACKWARD CINCH ANALYSIS
 (Values of both BLRENTM and BLAFFORDM are formatted)"; run;

PROC FREQ DATA=BLCINCH_DATA FORMCHAR(1,2,7)='   ' ; 
	TABLE  BLRENTM*BLAFFORDM/MISSING nocol norow nopercent F=COMMA6.; /* Dav added format */
	FORMAT BLRENTM BLRENTM. BLAFFORDM BLAFFORDM.; 
RUN;


ODS HTML CLOSE;
ODS LISTING;

