options pagesize=6000 linesize=110 compress=binary nocenter MPRINT MLOGIC NODATE NONUMBER;

libname OUT 'C:\NEW_AHS_2018\DOWN LOADED DATA AS OF OCT 2019';


******************************************************************************************;

ods HTML file="C:\NEW_AHS_2018\\DOWN LOADED DATA AS OF OCT 2019\CINCH_FORWARD_Weights_DETROIT.XLS";

***********************************************************************************;


***********************************************************************************;

/*******   The first part of this code is to adjust the weights till we obtain PWT15S2   *****/
/*******   In the second part we adjust the Weights PWT15S2  in several steps till we obtain PWT15S4a ****/



*******    The first Part:  Forward-Looking analysis to obtain PWT15S2 for DETRIOT **************************;
/*

Please combine AHS15 National with WDTG, keeping all cases with SAMPLETYPE = 1.  

*/

PROC SORT DATA=OUT.WDTG17; BY CONTROL;RUN;


DATA renamed_ahs15; SET OUT.renamed_ahs2015n;RUN;

PROC SORT DATA=renamed_ahs15; BY CONTROL;RUN;

DATA renamed_ahs17; SET OUT.renamed_ahs2017n;RUN;

PROC SORT DATA=renamed_ahs17; BY CONTROL;RUN;

DATA AHS15_AHS17; MERGE renamed_ahs15 (IN=AHS15) renamed_ahs17 (IN=AHS17); BY CONTROL; 
IF AHS15=1; RUN;

PROC SORT DATA=AHS15_AHS17; BY CONTROL;RUN;

DATA AHS15_AHS17_WDTG; MERGE AHS15_AHS17  OUT.WDTG17 ; BY CONTROL;
IF SAMPLETYPE = '1';

  * Note missing command was in already;
     missing B D R X _ H N M;
     MISSING b d r n m ;

RUN;

/*
Turn INTSTATUS15, NOINT15, INTSTATUS17, and NOINT17 into numeric variables.
	
Keep (SAMPLETYPE = 1 AND (0 < INTSTATUS15 <= 3 OR 0 < NOINT15 <= 6) AND OMB13CBSA = 19820). 
Call this file FLDETRIOT1517


Do an unweighted and weighted (using both PWT15 and WEIGHT) count of FLDETRIOT1517. 

Do unweighted and weighted (PWT15) frequency distributions of INTSTATUS15, NOINT15, INTSTATUS17, NOINT17

*/
DATA FLDETRIOT1517; SET AHS15_AHS17_WDTG;L=1;

IF  OMB13CBSA = '19820'; RUN;

DATA FLDETRIOT1517; SET  FLDETRIOT1517;

IF INTSTATUS15 IN('1','2','3') OR 0 LT NOINT15 LE 6; RUN;


TITLE "COUNT AND SUM OF PWT15 FROM FLDETRIOT1517"; RUN;

PROC MEANS DATA= FLDETRIOT1517 N SUM; VAR PWT15; 
OUTPUT OUT=SUM_PWT15 SUM=SUM_PWT15;RUN;

DATA SUM_PWT15; SET SUM_PWT15; L=1;
PROC SORT DATA=SUM_PWT15; BY L;


TITLE "COUNT AND SUM OF IN15_WEIGHT FROM FLDETRIOT1517"; RUN;

PROC MEANS DATA= FLDETRIOT1517 N SUM; VAR IN15_WEIGHT; RUN;


TITLE "Unweighted Freq Dist of INTSTATUS15, NOINT15, INTSTATUS17, NOINT17 FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSTATUS15 NOINT15 INTSTATUS17 NOINT17/MISSING ; RUN;

TITLE "Weighted (PWT15) Freq Dist of INTSTATUS15, NOINT15, INTSTATUS17, NOINT17 FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSTATUS15 NOINT15 INTSTATUS17 NOINT17/MISSING ;WEIGHT PWT15; RUN;

PROC SORT DATA=FLDETRIOT1517; BY L;RUN;


DATA FLDETRIOT1517; MERGE FLDETRIOT1517 SUM_PWT15; BY L;

PWT15S1 = PWT15*1895700/SUM_PWT15; RUN;


TITLE "COUNT AND SUM OF PWT15S1 FROM FLDETRIOT1517"; RUN;

PROC MEANS DATA= FLDETRIOT1517 N SUM; VAR PWT15S1; RUN;


/******** CREATE SAME AND LOSS   ***/

DATA FLDETRIOT1517; SET  FLDETRIOT1517;

SAME = 0;

IF (INTSTATUS17 IN('1','2','3') OR 0 LT NOINT17 LE 6) THEN SAME = 1;

LOSS = 0;

IF 10 LE NOINT17 LE 42 THEN LOSS = 1;RUN;


TITLE "Unweighted Freq Dist of SAME and LOSS FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE SAME  LOSS/MISSING ; RUN;

TITLE "Weighted (PWT15S1) Freq Dist of SAME and LOSS FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE SAME LOSS/MISSING ;WEIGHT PWT15S1; RUN;



PROC SORT DATA=FLDETRIOT1517;BY SAME; RUN;

PROC MEANS DATA=FLDETRIOT1517 SUM NOPRINT; VAR PWT15S1; 
OUTPUT OUT=SAME_SUM_PWT15S1 SUM=SAME_SUM_PWT15S1; BY SAME; RUN;

PROC SORT DATA=SAME_SUM_PWT15S1; BY SAME;RUN;

DATA FLDETRIOT1517; MERGE FLDETRIOT1517 SAME_SUM_PWT15S1; BY SAME; RUN;


PROC SORT DATA=FLDETRIOT1517;BY LOSS; RUN;

PROC MEANS DATA=FLDETRIOT1517 SUM NOPRINT; VAR PWT15S1; 
OUTPUT OUT=LOSS_SUM_PWT15S1 SUM=LOSS_SUM_PWT15S1; BY LOSS; RUN;

PROC SORT DATA=LOSS_SUM_PWT15S1; BY LOSS; RUN;

DATA FLDETRIOT1517; MERGE FLDETRIOT1517 LOSS_SUM_PWT15S1; BY LOSS; RUN;



/*
	Create INTSAME and INTLOSS as follows:
INTSAME = 0;
IF (0 < INSTATUS15 <= 3 AND 0 < INSTATUS17 <= 3) THEN INTSAME = 1;
INTLOSS = 0;
IF LOSS = 1 AND 0 < INTSTATUS 15 < 3 THEN INTLOSS = 1;
*/

DATA FLDETRIOT1517; SET  FLDETRIOT1517;

INTSAME = 0;

IF INTSTATUS15 IN('1','2','3')  and INTSTATUS17 IN('1','2','3') THEN INTSAME = 1;

INTLOSS = 0;

IF LOSS = 1 AND INTSTATUS15 IN('1','2') THEN INTLOSS = 1;RUN;

TITLE "Unweighted Cross Tab of same*INTSAME and loss*INTLOSS FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE SAME*INTSAME  LOSS*INTLOSS/MISSING NOROW NOCOL NOPERECENT; RUN;


TITLE "Unweighted Freq Dist of INTSAME and INTLOSS FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSAME  INTLOSS/MISSING ; RUN;

TITLE "Weighted (PWT15S1) Freq Dist of INTSAME and INTLOSS FROM FLDETRIOT1517"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSAME INTLOSS/MISSING ;WEIGHT PWT15S1; RUN;


PROC SORT DATA=FLDETRIOT1517;BY INTSAME; RUN;

PROC MEANS DATA=FLDETRIOT1517 SUM NOPRINT; VAR PWT15S1 ; 
OUTPUT OUT=INTSAME_SUM_PWT15S1 SUM=INTSAME_SUM_PWT15S1; BY INTSAME; RUN;

PROC SORT DATA=INTSAME_SUM_PWT15S1; BY INTSAME; RUN;

DATA FLDETRIOT1517; MERGE FLDETRIOT1517 INTSAME_SUM_PWT15S1;BY INTSAME; RUN;



PROC SORT DATA=FLDETRIOT1517;BY INTLOSS; RUN;

PROC MEANS DATA=FLDETRIOT1517 SUM NOPRINT; VAR PWT15S1; 
OUTPUT OUT=INTLOSS_SUM_PWT15S1 SUM=INTLOSS_SUM_PWT15S1; BY INTLOSS; RUN;

PROC SORT DATA=INTLOSS_SUM_PWT15S1; BY INTLOSS; RUN;

DATA FLDETRIOT1517; MERGE FLDETRIOT1517 INTLOSS_SUM_PWT15S1; BY INTLOSS; RUN;


/*
	Create PWT15S2 as follows:
PWT15S2 = 0
IF INTSAME =1 THEN PWT15S2 = PWT15S1*?SAME*PWTS1/ ?INTSAME*PWT15S1 where * means multiplication.
IF INTLOSS =1 THEN PWT15S2 = PWT15S1*?LOSS*PWTS1 / ?INTLOSS*PWT15S1 where * means multiplication.

*/

DATA FLDETRIOT1517; SET  FLDETRIOT1517;

PWT15S2 = 0;

IF INTSAME =1 THEN PWT15S2 = PWT15S1*SAME_SUM_PWT15S1/INTSAME_SUM_PWT15S1; 

IF INTLOSS =1 THEN PWT15S2 = PWT15S1*LOSS_SUM_PWT15S1/INTLOSS_SUM_PWT15S1; RUN;



TITLE "Weighted (PWT15S2) Freq Dist of INTSAME and INTLOSS FROM FLDETRIOT1517 
BEFORE SELECTINGN INTSAME=1 OR INTLOSS=1"; RUN;

PROC FREQ DATA=FLDETRIOT1517;TABLE INTSAME INTLOSS/MISSING ;WEIGHT PWT15S2; RUN;



DATA FLDETRIOT1517; SET  FLDETRIOT1517;

IF  INTSAME = 1 OR INTLOSS = 1;

RUN;


TITLE "Unweighted Freq Dist of INTSAME and INTLOSS FROM FLDETRIOT1517 AFTER SELECTING INTSAME=1 OR INTLOSS=1"; 
 RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSAME  INTLOSS/MISSING ; RUN;

TITLE "Weighted (PWT15S2) Freq Dist of INTSAME and INTLOSS FROM FLDETRIOT1517 
AFTER SELECTINGN INTSAME=1 OR INTLOSS=1"; RUN;
PROC FREQ DATA=FLDETRIOT1517;TABLE INTSAME INTLOSS/MISSING ;WEIGHT PWT15S2; RUN;


DATA FLDETRIOT1517; SET FLDETRIOT1517; RUN;


/*
Using the new FLDETRIOT1517, do unweighted and weighted (PWT15S2) frequency distributions of
IN15_TENURE
IN15_VACANCY
IN15_BLD
IN15_HHRACE
IN15_HHSPAN
1N15_YRBUILT
IN15_HHAGE
IN15_DISHH
*/

TITLE "UNWEIGHTED FREQ DIST OF SOME VARIABLES FROM FLDETRIOT1517"; RUN;

PROC  FREQ DATA=FLDETRIOT1517; TABLE IN15_TENURE
IN15_VACANCY IN15_BLD IN15_HHRACE IN15_HHSPAN IN15_YRBUILT IN15_HHAGE IN15_DISHH
/ MISSING; RUN;

TITLE "WEIGHTED (PWT15S2) FREQ DIST OF SOME VARIABLES FROM FLDETRIOT1517"; RUN;

PROC  FREQ DATA=FLDETRIOT1517; TABLE IN15_TENURE

IN15_VACANCY IN15_BLD IN15_HHRACE IN15_HHSPAN IN15_YRBUILT IN15_HHAGE IN15_DISHH/ 
MISSING;WEIGHT PWT15S2; RUN;

DATA FLDETROIT1517;set  FLDETRIOT1517;

  * Note missing command was in already;
     missing B D R X _ H N M;
     MISSING b d r n m ;


/**********************    HHAGE  ********************************/
                                        HHAGE="9-Other                ";

IF	0  LE IN15_HHAGE LT 25	THEN	HHAGE="1-Under 25 years old   ";

IF	25 LE IN15_HHAGE LT 30	THEN	HHAGE="2-25 to 29 years old   ";

IF	30 LE IN15_HHAGE LT 35	THEN	HHAGE="3-30 to 34 years old   ";

IF	35 LE IN15_HHAGE LT 45	THEN	HHAGE="4-35 to 44 years old   ";

IF	45 LE IN15_HHAGE LT 55	THEN	HHAGE="5-45 to 54 years old   ";

IF	55 LE IN15_HHAGE LT 65	THEN	HHAGE="6-55 to 64 years old   ";

IF	65 LE IN15_HHAGE LT 75	THEN	HHAGE="7-65 to 74 years old   ";

IF	75 LE IN15_HHAGE 	THEN	HHAGE="8-75 years old and over";


/* CHANGE IN15_IN15_HHRACE FROM CHARACTER TO NUMERIC*/

/*IN15_HHRACE_N=1*IN15_HHRACE;*/

                          RACE="6- HHRACE=N                              ";

IF IN15_HHRACE ='01' THEN RACE="1- White alone                           ";                   

IF IN15_HHRACE ='02' THEN RACE="2- Black alone                           ";

IF IN15_HHRACE ='03' THEN RACE="3- American Indian or Alaska Native alone";         

IF IN15_HHRACE ='04' THEN RACE="4- Asian alone                           ";                                 

IF IN15_HHRACE IN('05','06','07')
                     THEN RACE="5- Other Races                           ";



                           ETHNICITY="Other      ";

IF IN15_HHSPAN = '1'  THEN ETHNICITY="Hispanic   ";

IF IN15_HHSPAN = '2'  THEN ETHNICITY="NonHispanic";


                            YRBUILT="other";

IF IN15_YRBUILT=2010   THEN YRBUILT="2010 ";

IF IN15_YRBUILT=2000   THEN YRBUILT="2000 ";

IF IN15_YRBUILT=1990   THEN YRBUILT="1990 ";

IF IN15_YRBUILT=1980   THEN YRBUILT="1980 ";

IF IN15_YRBUILT=1970   THEN YRBUILT="1970 ";

IF IN15_YRBUILT=1960   THEN YRBUILT="1960 ";

IF IN15_YRBUILT=1950   THEN YRBUILT="1950 ";

IF IN15_YRBUILT=1940   THEN YRBUILT="1940 ";

IF IN15_YRBUILT=1930   THEN YRBUILT="1930 ";

IF IN15_YRBUILT=1920   THEN YRBUILT="1920 ";

IF IN15_YRBUILT=1919   THEN YRBUILT="1919 ";


                                 Structure_Type="9- other                   ";

IF IN15_BLD= '02'           THEN Structure_Type="1- 1, detached             ";

IF IN15_BLD= '03'           THEN Structure_Type="2- 1, attached             ";

IF IN15_BLD in('04','05')   THEN Structure_Type="3- 2 to 4                  ";

IF IN15_BLD= '06'           THEN Structure_Type="4- 5 to 9                  ";

IF IN15_BLD= '07'           THEN Structure_Type="5- 10 to 19                ";

IF IN15_BLD= '08'           THEN Structure_Type="6- 20 to 49                ";

IF IN15_BLD= '09'           THEN Structure_Type="7- 50 or more              ";

IF IN15_BLD in('01' ,'10')  THEN Structure_Type="8- Manufactured/mobile home";



                                 ROWS="7_Other                         ";

IF IN15_TENURE = '1'	    THEN ROWS="1-Owners                        ";

IF IN15_HUDSUB= '3'         THEN ROWS="2_Unassisted Renters            ";

IF IN15_HUDSUB= '1'         THEN ROWS="3_Public Housing/Privately owned";

IF IN15_HUDSUB= '2'         THEN ROWS="4_Voucher household             ";

IF IN15_VACANCY IN ('01','02','03','04','05','06','07')

                            THEN ROWS="5_Vacant                        ";

IF IN15_VACANCY IN ('08','09','10','11')

                            THEN ROWS="6_Seasonal                      ";

IF INTSAME = 1     THEN COLUMNS="1_INTSAME = 1";	

IF INTLOSS = 1     THEN COLUMNS="2_INTLOSS = 1";
RUN;

**********************************************************************************;

TITLE "UNWEIGHTED FREQ DIST OF IN15_TENURE  HHAGE IN15_HHRACE IN15_HHRACE RACE ETHNICITY YRBUILT Structure_Type ROWS COLUMNS from
FLDETROIT1517"; RUN;

PROC FREQ DATA=FLDETROIT1517; TABLE IN15_TENURE  HHAGE IN15_HHRACE RACE ETHNICITY IN15_YRBUILT YRBUILT Structure_Type ROWS 
COLUMNS/MISSING; RUN;

TITLE "WEIGHTED (PWT15S2) FREQ DIST OF HHAGE IN15_HHRACE RACE ETHNICITY YRBUILT Structure_Type ROWS COLUMNS from
FLDETROIT1517"; RUN;

PROC FREQ DATA=FLDETROIT1517; TABLE IN15_TENURE HHAGE RACE ETHNICITY YRBUILT Structure_Type ROWS 
COLUMNS/MISSING;WEIGHT PWT15S2; RUN;



**********************************************************************************;


/*****   a)	Adjusting for age of householder    ******/

PROC SORT DATA=FLDETROIT1517; BY HHAGE; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S2;

OUTPUT OUT=SUM_PWT15S2_HHAGE SUM=SUM_PWT15S2_HHAGE; BY HHAGE; RUN;

DATA SUM_PWT15S2_HHAGE; SET SUM_PWT15S2_HHAGE;

IF	HHAGE="1-Under 25 years old   "  THEN	a_a=49600	;
IF	HHAGE="2-25 to 29 years old   "  THEN	a_a=93700	;
IF	HHAGE="3-30 to 34 years old   "  THEN	a_a=142300	;
IF	HHAGE="4-35 to 44 years old   "  THEN	a_a=286700	;
IF	HHAGE="5-45 to 54 years old   "  THEN	a_a=353000	;
IF	HHAGE="6-55 to 64 years old   "  THEN	a_a=371300	;
IF	HHAGE="7-65 to 74 years old   "  THEN	a_a=235000	;
IF	HHAGE="8-75 years old and over"  THEN	a_a=177500	;


c_a=a_a/SUM_PWT15S2_HHAGE; 

IF      HHAGE="9-Other                "    THEN c_a=1;    RUN;


PROC SORT DATA=SUM_PWT15s2_HHAGE; BY HHAGE; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S2_HHAGE;BY HHAGE; 

PWT15S3a=PWT15S2*c_a;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY HHAGE; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3a;

OUTPUT OUT=SUM_PWT15S3a_HHAGE SUM=SUM_PWT15S3a_HHAGE ; BY HHAGE; RUN;


PROC SORT DATA=SUM_PWT15S3a_HHAGE; BY HHAGE; RUN;

DATA BOTH_S2_S3a; MERGE SUM_PWT15S2_HHAGE SUM_PWT15S3a_HHAGE; BY HHAGE; RUN;

TITLE "PRINT OF TABLES A B C D ADJUSTMENT FOR HHAGE"; RUN;

PROC PRINT DATA=BOTH_S2_S3a NOOBS; VAR HHAGE a_a
SUM_PWT15S2_HHAGE c_a SUM_PWT15S3a_HHAGE; RUN;

*****************************************************************************************;
/*******b)	Adjusting for race     ******/

PROC SORT DATA=FLDETROIT1517; BY RACE;RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3a;

OUTPUT OUT=SUM_PWT15S3a_RACE SUM=SUM_PWT15S3a_RACE ; BY RACE; RUN;


DATA SUM_PWT15S3a_RACE; SET SUM_PWT15S3a_RACE;

IF RACE="1- White alone                           " THEN        a_b=1203800;

IF RACE="2- Black alone                           " Then        a_b=418800;

IF RACE="4- Asian alone                           " THEN       	a_b=58200;


C_b=a_b/SUM_PWT15S3a_RACE;


IF RACE="3- American Indian or Alaska Native alone" THEN   c_b=1;   

IF RACE="5- Other Races                           " THEN   c_b=1;

IF RACE="6- HHRACE=N                              " THEN   c_b=1;RUN;


PROC SORT DATA=SUM_PWT15S3a_RACE; BY RACE; RUN;

DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S3a_RACE; BY RACE; 

PWT15S3b=PWT15S3a*c_b; RUN;


PROC SORT DATA=FLDETROIT1517; BY RACE; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3b;

OUTPUT OUT=SUM_PWT15S3b_RACE SUM=SUM_PWT15S3b_RACE; BY RACE; RUN;


PROC SORT DATA=SUM_PWT15S3b_RACE; BY RACE; RUN;


DATA BOTH_S3a_S3b; MERGE SUM_PWT15S3a_RACE SUM_PWT15S3b_RACE; BY RACE;RUN;

TITLE "PRINT OF TABLES A B C D ADJUSTMENT FOR RACE"; RUN;

PROC PRINT DATA=BOTH_S3a_S3b NOOBS; VAR RACE a_b SUM_PWT15S3a_RACE c_b SUM_PWT15S3b_RACE;RUN;


********************************************************************************************************;

/******c)	Adjusting for ethnicity     ******/


PROC SORT DATA=FLDETROIT1517; BY ETHNICITY; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3b;

OUTPUT OUT=SUM_PWT15S3b_ETHNICITY SUM=SUM_PWT15S3b_ETHNICITY ; BY ETHNICITY; RUN;


DATA SUM_PWT15S3b_ETHNICITY; SET SUM_PWT15S3b_ETHNICITY;

IF ETHNICITY="Hispanic   "   THEN a_c=50000   ; 

IF ETHNICITY="NonHispanic"   THEN a_c=1659000 ;


c_c=a_c/SUM_PWT15S3b_ETHNICITY;

IF ETHNICITY="Other      " THEN c_c=1;
RUN;

PROC SORT DATA=SUM_PWT15S3b_ETHNICITY; BY ETHNICITY; RUN;

DATA FLDETROIT1517; MERGE  FLDETROIT1517 SUM_PWT15S3b_ETHNICITY;BY ETHNICITY; 
PWT15S3c=PWT15S3b*c_c;   RUN;


PROC SORT DATA=FLDETROIT1517; BY ETHNICITY; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3c;

OUTPUT OUT=SUM_PWT15S3c_ETHNICITY SUM=SUM_PWT15S3c_ETHNICITY ; BY ETHNICITY; RUN;


PROC SORT DATA=SUM_PWT15S3c_ETHNICITY; BY ETHNICITY;RUN;

DATA BOTH_S3b_S3c; MERGE SUM_PWT15S3b_ETHNICITY SUM_PWT15S3c_ETHNICITY; BY ETHNICITY;

RUN;
TITLE "PRINT OF TABLES A B C D ADJUSTMENT FOR ETHNICITY"; RUN;

PROC PRINT DATA=BOTH_S3b_S3c NOOBS; VAR ETHNICITY a_c
SUM_PWT15S3b_ETHNICITY  c_c SUM_PWT15S3c_ETHNICITY; RUN;

*****************************************************************************************;

/*****d)	Adjusting for Year Built     ******/


PROC SORT DATA=FLDETROIT1517; BY YRBUILT; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3c;

OUTPUT OUT=SUM_PWT15S3c_YRBUILT SUM=SUM_PWT15S3c_YRBUILT; BY YRBUILT; RUN;

DATA SUM_PWT15S3c_YRBUILT; SET SUM_PWT15S3c_YRBUILT;

IF YRBUILT="2010 "   THEN a_d=21000;

IF YRBUILT="2000 "   THEN a_d=159700;

IF YRBUILT="1990 "   THEN a_d=223800;

IF YRBUILT="1980 "   THEN a_d=155600;

IF YRBUILT="1970 "   THEN a_d=271700;

IF YRBUILT="1960 "   THEN a_d=229700;

IF YRBUILT="1950 "   THEN a_d=371900;

IF YRBUILT="1940 "   THEN a_d=181600;

IF YRBUILT="1930 "   THEN a_d=72800;

IF YRBUILT="1920 "   THEN a_d=133500;

IF YRBUILT="1919 "   THEN a_d=74400;


c_d=a_d/SUM_PWT15S3c_YRBUILT; 

IF     YRBUILT="other" THEN c_d=1;

RUN;

PROC SORT DATA=SUM_PWT15S3c_YRBUILT; BY YRBUILT; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S3c_YRBUILT;BY YRBUILT; 

PWT15S3d=PWT15S3c*c_d;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY YRBUILT; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3d;

OUTPUT OUT=SUM_PWT15S3d_YRBUILT SUM=SUM_PWT15S3d_YRBUILT ; BY YRBUILT; RUN;


PROC SORT DATA=SUM_PWT15S3d_YRBUILT; BY YRBUILT; RUN;

DATA BOTH_S3c_S3d; MERGE SUM_PWT15S3c_YRBUILT SUM_PWT15S3d_YRBUILT; BY YRBUILT; RUN;

TITLE "PRINT OF TABLES A B C D ADJUSTMENT FOR YRBUILT"; RUN;

PROC PRINT DATA=BOTH_S3c_S3d NOOBS; VAR YRBUILT a_d
SUM_PWT15S3c_YRBUILT c_d SUM_PWT15S3d_YRBUILT; RUN;

*****************************************************************************************;

/*******e)	Adjusting for structure type     *****/

PROC SORT DATA=FLDETROIT1517; BY Structure_Type; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3d;

OUTPUT OUT=SUM_PWT15S3d_STR SUM=SUM_PWT15S3d_STR ; BY Structure_Type; RUN;



DATA SUM_PWT15S3d_STR; SET SUM_PWT15S3d_STR; 


IF Structure_Type="1- 1, detached             " THEN a_e=1357900;

IF Structure_Type="2- 1, attached             " THEN a_e=166300;

IF Structure_Type="3- 2 to 4                  " THEN a_e=73300;

IF Structure_Type="4- 5 to 9                  " THEN a_e=85000;

IF Structure_Type="5- 10 to 19                " THEN a_e=65400;

IF Structure_Type="6- 20 to 49                " THEN a_e=31400;

IF Structure_Type="7- 50 or more              " THEN a_e=67100;

IF Structure_Type="8- Manufactured/mobile home" THEN a_e=49300;


c_e=a_e/SUM_PWT15S3d_STR;

   
IF Structure_Type="9- other                   " THEN c_e=1; 

RUN;

PROC SORT DATA=SUM_PWT15S3d_STR; BY Structure_Type; RUN;

DATA FLDETROIT1517 ; MERGE FLDETROIT1517 SUM_PWT15S3d_STR; BY Structure_Type;

PWT15S3e=PWT15S3d*c_e;          RUN;


PROC SORT DATA=FLDETROIT1517; BY Structure_Type; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S3e;

OUTPUT OUT=SUM_PWT15S3e_STR SUM=SUM_PWT15S3e_STR ; BY Structure_Type; RUN;


PROC SORT DATA=SUM_PWT15S3e_STR; BY Structure_Type; RUN;

DATA BOTH_S3d_S3e;MERGE SUM_PWT15S3d_STR SUM_PWT15S3e_STR; 
BY Structure_Type; RUN;

TITLE "PRINT OF TABLES A B C D ADJUSTMENT FOR Structure_Type"; RUN;

PROC PRINT DATA=BOTH_S3d_S3e NOOBS;VAR Structure_Type  a_e SUM_PWT15S3d_STR  c_e 
SUM_PWT15S3e_STR; RUN;


********************************************************************************************;
/***** RENAME The lst weight we got above PWT15S3e to be PWT15S4a   ****/

DATA FLDETROIT1517; SET FLDETROIT1517; 

PWT15S4a=PWT15S3e;  RUN;

**********************************************************************************************;


/* ITERATION 1	Rake 1 step 1: Use PWT15S4a and the code in column A to estimate rows 3-8 in column E   */


PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4a;

OUTPUT OUT=SUM_PWT15S4a_ROWS SUM=SUM_PWT15S4a_ROWS; BY ROWS; RUN;


DATA SUM_PWT15S4a_ROWS; SET SUM_PWT15S4a_ROWS;

IF ROWS="1-Owners                        " THEN	a_g=1189000;
IF ROWS="2_Unassisted Renters            " THEN	a_g=457300;
IF ROWS="3_Public Housing/Privately owned" THEN	a_g=37300;
IF ROWS="4_Voucher household             " THEN	a_g=25400;
IF ROWS="5_Vacant                        " THEN	a_g=176800;
IF ROWS="6_Seasonal                      " THEN	a_g=9900;


c_g=a_g/SUM_PWT15S4a_ROWS; 

IF ROWS="7-Other                         " THEN	C_g=1;
RUN;

PROC SORT DATA=SUM_PWT15S4a_ROWS; BY ROWS; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4a_ROWS;BY ROWS; 

PWT15S4b1=PWT15S4a*c_g;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b1;

OUTPUT OUT=SUM_PWT15S4b1_ROWS SUM=SUM_PWT15S4b1_ROWS ; BY ROWS; RUN;


PROC SORT DATA=SUM_PWT15S4b1_ROWS; BY ROWS; RUN;

DATA SUM_PWT15S4b1_ROWS; MERGE SUM_PWT15S4a_ROWS SUM_PWT15S4b1_ROWS; BY ROWS; RUN;

TITLE "ITERATION 1: PRINT OF TABLES A B C D ADJUSTMENT FOR ROWS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b1_ROWS NOOBS; VAR ROWS a_g
SUM_PWT15S4a_ROWS c_g SUM_PWT15S4b1_ROWS; RUN;



*****************************************************************************************;
/*************ITERATION 2: Rake 2 Step 1	Adjusting for INTSAME and INTLOSS.  *******/

PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;


PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR  PWT15S4b1;

OUTPUT OUT=SUM_PWT15S4b1_COLUMNS SUM=SUM_PWT15S4b1_COLUMNS; BY COLUMNS; RUN;

DATA SUM_PWT15S4b1_COLUMNS; SET SUM_PWT15S4b1_COLUMNS;


IF COLUMNS="1_INTSAME = 1" THEN a_h=1872910;
IF COLUMNS="2_INTLOSS = 1" THEN a_h=22790;


c_h=a_h/SUM_PWT15S4b1_COLUMNS;  RUN;

PROC SORT DATA=SUM_PWT15S4b1_COLUMNS;BY COLUMNS; RUN; 


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b1_COLUMNS;BY COLUMNS; 

PWT15S4b2=PWT15S4b1*c_h;        RUN;


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b2;

OUTPUT OUT=SUM_PWT15S4b2_COLUMNS SUM=SUM_PWT15S4b2_COLUMNS ; BY COLUMNS; RUN;


PROC SORT DATA=SUM_PWT15S4b2_COLUMNS; BY COLUMNS; RUN;


DATA SUM_PWT15S4b2_COLUMNS; MERGE SUM_PWT15S4b2_COLUMNS SUM_PWT15S4b1_COLUMNS;

BY COLUMNS; RUN;


TITLE "ITERATION 2: PRINT OF TABLES A B C D ADJUSTMENT FOR COLUMNS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b2_COLUMNS NOOBS; VAR COLUMNS a_h
SUM_PWT15S4b1_COLUMNS c_h SUM_PWT15S4b2_COLUMNS; RUN;

*****************************************************************************************;

/*	ITERATION # 3  IN TE RACKING ITERATION

Rake : step 1: Use PWT15S4b and the code in column A to estimate rows 3-8 in column E   */


PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b2;

OUTPUT OUT=SUM_PWT15S4b2_ROWS SUM=SUM_PWT15S4b2_ROWS; BY ROWS; RUN;

DATA SUM_PWT15S4b2_ROWS; SET SUM_PWT15S4b2_ROWS;


IF ROWS="1-Owners                        " THEN	a_g=1189000;
IF ROWS="2_Unassisted Renters            " THEN	a_g=457300;
IF ROWS="3_Public Housing/Privately owned" THEN	a_g=37300;
IF ROWS="4_Voucher household             " THEN	a_g=25400;
IF ROWS="5_Vacant                        " THEN	a_g=176800;
IF ROWS="6_Seasonal                      " THEN	a_g=9900;

d_g=a_g/SUM_PWT15S4b2_ROWS; 

IF ROWS="7-Other                         " THEN	d_g=1;

RUN;

PROC SORT DATA=SUM_PWT15S4b2_ROWS; BY ROWS; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b2_ROWS;BY ROWS; 

PWT15S4b3=PWT15S4b2*d_g;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b3;

OUTPUT OUT=SUM_PWT15S4b3_ROWS SUM=SUM_PWT15S4b3_ROWS ; BY ROWS; RUN;


PROC SORT DATA=SUM_PWT15S4b3_ROWS; BY ROWS; RUN;

DATA SUM_PWT15S4b3_ROWS; MERGE SUM_PWT15S4b2_ROWS SUM_PWT15S4b3_ROWS; BY ROWS; RUN;

TITLE "ITERATION 3: PRINT OF TABLES A B C D ADJUSTMENT FOR ROWS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b3_ROWS NOOBS; VAR ROWS a_g
SUM_PWT15S4b2_ROWS d_g SUM_PWT15S4b3_ROWS; RUN;



*****************************************************************************************;
/*************  ITERATION # 4  IN TE RACKING ITERATION
Rake 2 Step 1	Adjusting for INTSAME and INTLOSS.  *******/


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;


PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR  PWT15S4b3;

OUTPUT OUT=SUM_PWT15S4b3_COLUMNS SUM=SUM_PWT15S4b3_COLUMNS; BY COLUMNS; RUN;

DATA SUM_PWT15S4b3_COLUMNS; SET SUM_PWT15S4b3_COLUMNS;


IF COLUMNS="1_INTSAME = 1" THEN a_h=1872910;
IF COLUMNS="2_INTLOSS = 1" THEN a_h=22790;

d_h=a_h/SUM_PWT15S4b3_COLUMNS;
  RUN;


PROC SORT DATA=SUM_PWT15S4b3_COLUMNS;BY COLUMNS; RUN; 


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b3_COLUMNS;BY COLUMNS; 

PWT15S4b4=PWT15S4b3*d_h;        RUN;


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b4;

OUTPUT OUT=SUM_PWT15S4b4_COLUMNS SUM=SUM_PWT15S4b4_COLUMNS ;BY  COLUMNS; RUN;


PROC SORT DATA=SUM_PWT15S4b4_COLUMNS; BY COLUMNS; RUN;


DATA SUM_PWT15S4b4_COLUMNS; MERGE SUM_PWT15S4b4_COLUMNS SUM_PWT15S4b3_COLUMNS;

BY COLUMNS; RUN;


TITLE "ITERATION 4: PRINT OF TABLES A B C D ADJUSTMENT FOR COLUMNS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b4_COLUMNS NOOBS; VAR COLUMNS a_h
SUM_PWT15S4b3_COLUMNS d_h SUM_PWT15S4b4_COLUMNS; RUN;

***************************************************************************************************;

/*	 ITERATION # 5  IN TE RACKING ITERATION 
Rake 1 step 1: Use PWT15S4a and the code in column A to estimate rows 3-8 in column E   */


PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b4;

OUTPUT OUT=SUM_PWT15S4b4_ROWS SUM=SUM_PWT15S4b4_ROWS; BY ROWS; RUN;



DATA SUM_PWT15S4b4_ROWS; SET SUM_PWT15S4b4_ROWS;

IF ROWS="1-Owners                        " THEN	a_g=1189000;
IF ROWS="2_Unassisted Renters            " THEN	a_g=457300;
IF ROWS="3_Public Housing/Privately owned" THEN	a_g=37300;
IF ROWS="4_Voucher household             " THEN	a_g=25400;
IF ROWS="5_Vacant                        " THEN	a_g=176800;
IF ROWS="6_Seasonal                      " THEN	a_g=9900;

e_g=a_g/SUM_PWT15S4b4_ROWS; 

IF ROWS="7-Other                         " THEN	e_g=1;


RUN;

PROC SORT DATA=SUM_PWT15S4b4_ROWS; BY ROWS; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b4_ROWS;BY ROWS; 

PWT15S4b5=PWT15S4b4*e_g;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b5;

OUTPUT OUT=SUM_PWT15S4b5_ROWS SUM=SUM_PWT15S4b5_ROWS ; BY ROWS; RUN;


PROC SORT DATA=SUM_PWT15S4b5_ROWS; BY ROWS; RUN;

DATA SUM_PWT15S4b5_ROWS; MERGE SUM_PWT15S4b4_ROWS SUM_PWT15S4b5_ROWS; BY ROWS; RUN;

TITLE "ITERATION 5: PRINT OF TABLES A B C D ADJUSTMENT FOR ROWS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b5_ROWS NOOBS; VAR ROWS a_g
SUM_PWT15S4b4_ROWS e_g SUM_PWT15S4b5_ROWS; RUN;



*****************************************************************************************;
/*************  ITERATION # 6  IN TE RACKING ITERATION
Rake 2 Step 1	Adjusting for INTSAME and INTLOSS.  *******/


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;


PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR  PWT15S4b5;

OUTPUT OUT=SUM_PWT15S4b5_COLUMNS SUM=SUM_PWT15S4b5_COLUMNS; BY COLUMNS; RUN;

DATA SUM_PWT15S4b5_COLUMNS; SET SUM_PWT15S4b5_COLUMNS;



IF COLUMNS="1_INTSAME = 1" THEN a_h=1872910;
IF COLUMNS="2_INTLOSS = 1" THEN a_h=22790;

e_h=a_h/SUM_PWT15S4b5_COLUMNS;

  RUN;


PROC SORT DATA=SUM_PWT15S4b5_COLUMNS;BY COLUMNS; RUN; 


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b5_COLUMNS;BY COLUMNS; 

PWT15S4b6=PWT15S4b5*e_h;        RUN;


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b6;

OUTPUT OUT=SUM_PWT15S4b6_COLUMNS SUM=SUM_PWT15S4b6_COLUMNS ;BY  COLUMNS; RUN;


PROC SORT DATA=SUM_PWT15S4b6_COLUMNS; BY COLUMNS; RUN;


DATA SUM_PWT15S4b6_COLUMNS; MERGE SUM_PWT15S4b6_COLUMNS SUM_PWT15S4b5_COLUMNS;

BY COLUMNS; RUN;


TITLE "ITERATION 6: PRINT OF TABLES A B C D ADJUSTMENT FOR COLUMNS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b6_COLUMNS NOOBS; VAR COLUMNS a_h
SUM_PWT15S4b5_COLUMNS e_h SUM_PWT15S4b6_COLUMNS; RUN;

*****************************************************************************************;

/*	  ITERATION # 7  IN TE RACKING ITERATION
Rake 1 step 1: Use PWT15S4a and the code in column A to estimate rows 3-8 in column E   */


PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b6;

OUTPUT OUT=SUM_PWT15S4b6_ROWS SUM=SUM_PWT15S4b6_ROWS; BY ROWS; RUN;



DATA SUM_PWT15S4b6_ROWS; SET SUM_PWT15S4b6_ROWS;


IF ROWS="1-Owners                        " THEN	a_g=1189000;
IF ROWS="2_Unassisted Renters            " THEN	a_g=457300;
IF ROWS="3_Public Housing/Privately owned" THEN	a_g=37300;
IF ROWS="4_Voucher household             " THEN	a_g=25400;
IF ROWS="5_Vacant                        " THEN	a_g=176800;
IF ROWS="6_Seasonal                      " THEN	a_g=9900;


f_g=a_g/SUM_PWT15S4b6_ROWS; 

IF ROWS="7-Other                         " THEN	f_g=1;

RUN;

PROC SORT DATA=SUM_PWT15S4b6_ROWS; BY ROWS; RUN;


DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b6_ROWS;BY ROWS; 

PWT15S4b7=PWT15S4b6*f_g;     RUN;
 
PROC SORT DATA=FLDETROIT1517; BY ROWS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b7;

OUTPUT OUT=SUM_PWT15S4b7_ROWS SUM=SUM_PWT15S4b7_ROWS ; BY ROWS; RUN;


PROC SORT DATA=SUM_PWT15S4b7_ROWS; BY ROWS; RUN;

DATA SUM_PWT15S4b7_ROWS; MERGE SUM_PWT15S4b6_ROWS SUM_PWT15S4b7_ROWS; BY ROWS; RUN;

TITLE "ITERATION 7: PRINT OF TABLES A B C D ADJUSTMENT FOR ROWS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b7_ROWS NOOBS; VAR ROWS a_g
SUM_PWT15S4b6_ROWS f_g SUM_PWT15S4b7_ROWS; RUN;



*****************************************************************************************;
/************* ITERATION # 8  IN TE RACKING ITERATION


Rake 2 Step 1	Adjusting for INTSAME and INTLOSS.  *******/


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;


PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR  PWT15S4b7;

OUTPUT OUT=SUM_PWT15S4b7_COLUMNS SUM=SUM_PWT15S4b7_COLUMNS; BY COLUMNS; RUN;

DATA SUM_PWT15S4b7_COLUMNS; SET SUM_PWT15S4b7_COLUMNS;



IF COLUMNS="1_INTSAME = 1" THEN a_h=1872910;
IF COLUMNS="2_INTLOSS = 1" THEN a_h=22790;

f_h=a_h/SUM_PWT15S4b7_COLUMNS;

  RUN;


PROC SORT DATA=SUM_PWT15S4b7_COLUMNS;BY COLUMNS; RUN; 


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

DATA FLDETROIT1517; MERGE FLDETROIT1517 SUM_PWT15S4b7_COLUMNS;BY COLUMNS; 

PWT15S4b8=PWT15S4b7*f_h;        RUN;


PROC SORT DATA=FLDETROIT1517; BY COLUMNS; RUN;

PROC MEANS DATA=FLDETROIT1517 NOPRINT SUM; VAR PWT15S4b8;

OUTPUT OUT=SUM_PWT15S4b8_COLUMNS SUM=SUM_PWT15S4b8_COLUMNS ;BY  COLUMNS; RUN;


PROC SORT DATA=SUM_PWT15S4b8_COLUMNS; BY COLUMNS; RUN;


DATA SUM_PWT15S4b8_COLUMNS; MERGE SUM_PWT15S4b8_COLUMNS SUM_PWT15S4b7_COLUMNS;

BY COLUMNS; RUN;


TITLE "ITERATION 8: PRINT OF TABLES A B C D ADJUSTMENT FOR COLUMNS"; RUN;

PROC PRINT DATA=SUM_PWT15S4b8_COLUMNS NOOBS; VAR COLUMNS a_h
SUM_PWT15S4b7_COLUMNS f_h SUM_PWT15S4b8_COLUMNS; RUN;

*****************************************************************************************;

*****************************************************************************************;

DATA OUT.FLCINCH_DETROIT;SET FLDETROIT1517;

FLCINCHWT=PWT15S4b8;

RUN;
/*
	Using FLDETROIT1517, do unweighted and weighted (FLCINCHWT) frequency distributions of:
IN15_TENURE
IN15_VACANCY
IN15_BLD
IN15_HHRACE
IN15_HHSPAN
1N15_YRBUILT
IN15_HHAGE
IN15_DISHH
*/


TITLE "UNWEIGHTED FREQ DIST OF SOME VARIABLES FROM OUT.FLCINCH_DETROIT"; RUN;

PROC  FREQ DATA=OUT.FLCINCH_DETROIT; TABLE IN15_TENURE
IN15_VACANCY IN15_BLD IN15_HHRACE IN15_HHSPAN IN15_YRBUILT IN15_HHAGE IN15_DISHH
/ MISSING; RUN;

TITLE "WEIGHTED (FLCINCHWT) FREQ DIST OF SOME VARIABLES FROM OUT.FLCINCH_DETROIT"; RUN;

PROC  FREQ DATA=OUT.FLCINCH_DETROIT; TABLE IN15_TENURE

IN15_VACANCY IN15_BLD IN15_HHRACE IN15_HHSPAN IN15_YRBUILT IN15_HHAGE IN15_DISHH/ 
MISSING;WEIGHT FLCINCHWT; RUN;
